﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;
using UnityEngine.SceneManagement;

public class GameController : MonoBehaviour {

    public GameController gameController;
	public GameThemeManager themeManager;
    public GameAnimations gameAnimations;

	public AudioSource dingGoodSound;
	public AudioSource dingBadSound;
	public AudioSource levelUpSound;

	public Text introText;
	public Image introImage;
	public GameObject introTextObj;
	public GameObject introImageObj;

	public float introAlpha = 1.0f;
	public bool fadeIntro = false;

	public GameObject onsetTopObj;
	public GameObject rimeTopObj;

	public GameObject scoreTextObj;
	public GameObject timeTextObj;
	public GameObject levelTextObj;

	public GameObject[] onsetsList;
	public GameObject[] rimesList;

    public Button volumeButton;
    public Image volumeButtonImage;

    public Sprite volumeImageWhiteOff;
    public Sprite volumeImageWhiteOn;
    public Sprite volumeImageBlackOff;
    public Sprite volumeImageBlackOn;

	Image onsetTopImage;
	Image rimeTopImage;

	Text scoreText;
	Text timeText;
	Text levelText;

    public Text countdownText;

	public int score = 0;
	public int level = 1;

	public int timeLeft = 60;
	public int hideWordCountDown = 1;
	public int hideFooterCountDown = 1;

	bool isPro = true;
    bool endingGame = false;

	int min_difficulty_onset = 0;
	int max_difficulty_onset = 2;

	int min_difficulty_rime = 0;
	int max_difficulty_rime = 2;

	public bool onsetPressed = false;
	public bool rimePressed = false;
	bool hasStarted = false;
	int timeLeftToStart = 3;
	public WordList wordList;

	List<string> pickedOnsets = new List<string>();
	List<string> pickedRimes = new List<string>();

	public string tempWord = "";

	public OnsetTop onsetTop;
	public RimeTop rimeTop;

	public bool wordMade = false;

	public Text wordMadeFooter;
	public float wordMadeAlpha = 0.0f;
	public bool showFooter = false;
    public bool footerShown = false;
	public bool hideFooter = false;
    public float footerTime = 2.0f;

	public int introCountDown = 3;

	public string current_theme;
	public string current_sound;

	public string wordsMade;

	public Image topBgImage;
	public Image footerImage;

    public Image curOnsetImage;
    public Image curRimeImage;

    public bool fadeToGreen = false;
    public bool doneFadeToGreen = false;

    public float curCol = 1.0f;

    public bool fadeToRed = false;
    public bool doneFadeToRed = false;

    public AudioSource countdownAudio;

    public bool freeMode = false;

    int numWordsMade = 0;

	// Use this for initialization
	void Start () {

        if (PlayerPrefs.GetInt("freeMode") == 1)
        {
            freeMode = true;
        } else {
            freeMode = false;
        }

		// Make sure everything is reset to default.
		resetValues();

		// Connect all the GameObjects to the code
		// by their tags.
		initObjects();

		// Set the theme.
		setCurrentTheme();

		// Start the game timer.
		StartCoroutine(IntroCountdown());

		pickOnsets();
		pickRimes();

		current_theme = PlayerPrefs.GetString("cur_theme");
		current_sound = PlayerPrefs.GetString("cur_sound");


        checkVolume();


	}

    public void volumeButtonPressed() {
        
        int volOn = PlayerPrefs.GetInt("volume_on");
        if (volOn == 1) {
            if (PlayerPrefs.GetString("cur_theme").Equals("pastel")) {
                volumeButtonImage.sprite = volumeImageBlackOff;
            } else {
                volumeButtonImage.sprite = volumeImageWhiteOff;    
            }
            PlayerPrefs.SetInt("volume_on", 0);
        } else if (volOn == 0) {
            if (PlayerPrefs.GetString("cur_theme").Equals("pastel"))
            {
                volumeButtonImage.sprite = volumeImageBlackOn;
            } else {
                volumeButtonImage.sprite = volumeImageWhiteOn;
            }
            PlayerPrefs.SetInt("volume_on", 1);
        }

    }

	public void endGame () {

        SceneManager.LoadScene("01 - Main Menu", LoadSceneMode.Single);

	}

	public void setCurrentTheme () {

		if(PlayerPrefs.GetString("cur_sound").Equals("classic")){
			dingGoodSound.clip = themeManager.dingGoodClassic;
			dingBadSound.clip = themeManager.dingBadClassic;
			levelUpSound.clip = themeManager.levelUpClassic;
		}
		if(PlayerPrefs.GetString("cur_sound").Equals("techno")){
			dingGoodSound.clip = themeManager.dingGoodTechno;
			dingBadSound.clip = themeManager.dingBadTechno;
			levelUpSound.clip = themeManager.levelUpTechno;
		}
		if(PlayerPrefs.GetString("cur_sound").Equals("bamboo")){
			dingGoodSound.clip = themeManager.dingGoodBamboo;
			dingBadSound.clip = themeManager.dingBadBamboo;
			levelUpSound.clip = themeManager.levelUpBamboo;
		}
		if(PlayerPrefs.GetString("cur_sound").Equals("night")){
			dingGoodSound.clip = themeManager.dingGoodNight;
			dingBadSound.clip = themeManager.dingBadNight;
			levelUpSound.clip = themeManager.levelUpNight;
		}
		if(PlayerPrefs.GetString("cur_sound").Equals("candy")){
			dingGoodSound.clip = themeManager.dingGoodCandy;
			dingBadSound.clip = themeManager.dingBadCandy;
			levelUpSound.clip = themeManager.levelUpCandy;
		}
		if(PlayerPrefs.GetString("cur_sound").Equals("pastel")){
			dingGoodSound.clip = themeManager.dingGoodPastel;
			dingBadSound.clip = themeManager.dingBadPastel;
			levelUpSound.clip = themeManager.levelUpPastel;
		}

		if(PlayerPrefs.GetString("cur_theme").Equals("classic")){
			
			Debug.Log("classic");
			topBgImage.sprite = themeManager.topBgImgClassic;
			footerImage.sprite = themeManager.footerImgClassic;
			foreach (GameObject onset in onsetsList){
				onset.GetComponent<Image>().sprite = themeManager.onsetImgClassic;
				onset.GetComponent<OnsetObject>().valueText.color = Color.white;
			}
			foreach (GameObject rime in rimesList){
				rime.GetComponent<Image>().sprite = themeManager.rimeImgClassic;
				rime.GetComponent<RimeObject>().valueText.color = Color.white;
			}
			onsetTop.GetComponent<Image>().sprite = themeManager.onsetImgClassic;
			rimeTop.GetComponent<Image>().sprite = themeManager.rimeImgClassic;

			Color tmpCol = onsetTop.GetComponent<OnsetTop>().valueText.color;
			tmpCol.r = 1.0f;
			tmpCol.g = 1.0f;
			tmpCol.b = 1.0f;
			tmpCol.a = 0;
			onsetTop.GetComponent<OnsetTop>().valueText.color = tmpCol;

			tmpCol = rimeTop.GetComponent<RimeTop>().valueText.color;
			tmpCol.r = 1.0f;
			tmpCol.g = 1.0f;
			tmpCol.b = 1.0f;
			tmpCol.a = 0;
			rimeTop.GetComponent<RimeTop>().valueText.color = tmpCol;

			scoreText.color = Color.white;
			timeText.color = Color.white;
			levelText.color = Color.white;

		} else if(PlayerPrefs.GetString("cur_theme").Equals("techno")){
			
			Debug.Log("techno");
			topBgImage.sprite = themeManager.topBgImgTechno;
			footerImage.sprite = themeManager.footerImgTechno;
			foreach (GameObject onset in onsetsList){
				onset.GetComponent<Image>().sprite = themeManager.onsetImgTechno;
				onset.GetComponent<OnsetObject>().valueText.color = Color.white;
			}
			foreach (GameObject rime in rimesList){
				rime.GetComponent<Image>().sprite = themeManager.rimeImgTechno;
				rime.GetComponent<RimeObject>().valueText.color = Color.white;
			}
			onsetTop.GetComponent<Image>().sprite = themeManager.onsetImgTechno;
			rimeTop.GetComponent<Image>().sprite = themeManager.rimeImgTechno;

			Color tmpCol = onsetTop.GetComponent<OnsetTop>().valueText.color;
			tmpCol.r = 1.0f;
			tmpCol.g = 1.0f;
			tmpCol.b = 1.0f;
			tmpCol.a = 0;
			onsetTop.GetComponent<OnsetTop>().valueText.color = tmpCol;

			tmpCol = rimeTop.GetComponent<RimeTop>().valueText.color;
			tmpCol.r = 1.0f;
			tmpCol.g = 1.0f;
			tmpCol.b = 1.0f;
			tmpCol.a = 0;
			rimeTop.GetComponent<RimeTop>().valueText.color = tmpCol;

			scoreText.color = Color.white;
			timeText.color = Color.white;
			levelText.color = Color.white;

		} else if(PlayerPrefs.GetString("cur_theme").Equals("bamboo")){
			
			Debug.Log("bamboo");
			topBgImage.sprite = themeManager.topBgImgBamboo;
			footerImage.sprite = themeManager.footerImgBamboo;
			foreach (GameObject onset in onsetsList){
				onset.GetComponent<Image>().sprite = themeManager.onsetImgBamboo;
				onset.GetComponent<OnsetObject>().valueText.color = Color.white;
			}
			foreach (GameObject rime in rimesList){
				rime.GetComponent<Image>().sprite = themeManager.rimeImgBamboo;
				rime.GetComponent<RimeObject>().valueText.color = Color.white;
			}
			onsetTop.GetComponent<Image>().sprite = themeManager.onsetImgBamboo;
			rimeTop.GetComponent<Image>().sprite = themeManager.rimeImgBamboo;

			Color tmpCol = onsetTop.GetComponent<OnsetTop>().valueText.color;
			tmpCol.r = 1.0f;
			tmpCol.g = 1.0f;
			tmpCol.b = 1.0f;
			tmpCol.a = 0;
			onsetTop.GetComponent<OnsetTop>().valueText.color = tmpCol;

			tmpCol = rimeTop.GetComponent<RimeTop>().valueText.color;
			tmpCol.r = 1.0f;
			tmpCol.g = 1.0f;
			tmpCol.b = 1.0f;
			tmpCol.a = 0;
			rimeTop.GetComponent<RimeTop>().valueText.color = tmpCol;

			scoreText.color = Color.white;
			timeText.color = Color.white;
			levelText.color = Color.white;

		} else if(PlayerPrefs.GetString("cur_theme").Equals("night")){
			
			Debug.Log("night");
			topBgImage.sprite = themeManager.topBgImgNight;
			footerImage.sprite = themeManager.footerImgNight;
			foreach (GameObject onset in onsetsList){
				onset.GetComponent<Image>().sprite = themeManager.onsetImgNight;
                onset.GetComponent<OnsetObject>().onsetText.color = Color.white;
				onset.GetComponent<OnsetObject>().valueText.color = Color.white;
			}
			foreach (GameObject rime in rimesList){
				rime.GetComponent<Image>().sprite = themeManager.rimeImgNight;
                rime.GetComponent<RimeObject>().rimeText.color = Color.white;
				rime.GetComponent<RimeObject>().valueText.color = Color.white;
			}
			onsetTop.GetComponent<Image>().sprite = themeManager.onsetImgNight;
			rimeTop.GetComponent<Image>().sprite = themeManager.rimeImgNight;

			Color tmpCol = onsetTop.GetComponent<OnsetTop>().valueText.color;
			tmpCol.r = 1.0f;
			tmpCol.g = 1.0f;
			tmpCol.b = 1.0f;
			tmpCol.a = 0;
            onsetTop.GetComponent<OnsetTop>().onsetText.color = tmpCol;
			onsetTop.GetComponent<OnsetTop>().valueText.color = tmpCol;

			tmpCol = rimeTop.GetComponent<RimeTop>().valueText.color;
			tmpCol.r = 1.0f;
			tmpCol.g = 1.0f;
			tmpCol.b = 1.0f;
			tmpCol.a = 0;
            rimeTop.GetComponent<RimeTop>().rimeText.color = tmpCol;
			rimeTop.GetComponent<RimeTop>().valueText.color = tmpCol;

			scoreText.color = Color.white;
			timeText.color = Color.white;
			levelText.color = Color.white;

		} else if(PlayerPrefs.GetString("cur_theme").Equals("candy")){
			
			Debug.Log("candy");
			topBgImage.sprite = themeManager.topBgImgCandy;
			footerImage.sprite = themeManager.footerImgCandy;
			foreach (GameObject onset in onsetsList){
				onset.GetComponent<Image>().sprite = themeManager.onsetImgCandy;
                onset.GetComponent<OnsetObject>().onsetText.color = Color.white;
				onset.GetComponent<OnsetObject>().valueText.color = Color.white;
			}
			foreach (GameObject rime in rimesList){
				rime.GetComponent<Image>().sprite = themeManager.rimeImgCandy;
                rime.GetComponent<RimeObject>().rimeText.color = Color.white;
                rime.GetComponent<RimeObject>().valueText.color = Color.white;
			}
			onsetTop.GetComponent<Image>().sprite = themeManager.onsetImgCandy;
			rimeTop.GetComponent<Image>().sprite = themeManager.rimeImgCandy;

			Color tmpCol = onsetTop.GetComponent<OnsetTop>().valueText.color;
			tmpCol.r = 1.0f;
			tmpCol.g = 1.0f;
			tmpCol.b = 1.0f;
			tmpCol.a = 0;
            onsetTop.GetComponent<OnsetTop>().onsetText.color = tmpCol;
			onsetTop.GetComponent<OnsetTop>().valueText.color = tmpCol;

			tmpCol = rimeTop.GetComponent<RimeTop>().valueText.color;
			tmpCol.r = 1.0f;
			tmpCol.g = 1.0f;
			tmpCol.b = 1.0f;
			tmpCol.a = 0;
            rimeTop.GetComponent<RimeTop>().rimeText.color = tmpCol;
			rimeTop.GetComponent<RimeTop>().valueText.color = tmpCol;

			scoreText.color = Color.white;
			timeText.color = Color.white;
			levelText.color = Color.white;

		} else if(PlayerPrefs.GetString("cur_theme").Equals("pastel")){
			
			Debug.Log("pastel");
			topBgImage.sprite = themeManager.topBgImgPastel;
			footerImage.sprite = themeManager.footerImgPastel;
			foreach (GameObject onset in onsetsList){
				onset.GetComponent<Image>().sprite = themeManager.onsetImgPastel;
				onset.GetComponent<OnsetObject>().valueText.color = Color.black;
			}
			foreach (GameObject rime in rimesList){
				rime.GetComponent<Image>().sprite = themeManager.rimeImgPastel;
				rime.GetComponent<RimeObject>().valueText.color = Color.black;
			}
			onsetTop.GetComponent<Image>().sprite = themeManager.onsetImgPastel;
			rimeTop.GetComponent<Image>().sprite = themeManager.rimeImgPastel;

			Color tmpCol = onsetTop.GetComponent<OnsetTop>().valueText.color;
			tmpCol.r = 0;
			tmpCol.g = 0;
			tmpCol.b = 0;
			tmpCol.a = 0;
			onsetTop.GetComponent<OnsetTop>().valueText.color = tmpCol;

			tmpCol = rimeTop.GetComponent<RimeTop>().valueText.color;
			tmpCol.r = 0;
			tmpCol.g = 0;
			tmpCol.b = 0;
			tmpCol.a = 0;
			rimeTop.GetComponent<RimeTop>().valueText.color = tmpCol;

			scoreText.color = Color.black;
			timeText.color = Color.black;
			levelText.color = Color.black;

		}

	}

	void pickOnsets () {

		foreach (GameObject onset in onsetsList){
			
			int randDiff = Random.Range(min_difficulty_onset,max_difficulty_onset);
			string[] onsetList = {""};

			if(randDiff==0)onsetList = wordList.onsetList1;
			if(randDiff==1)onsetList = wordList.onsetList2;
			if(randDiff==2)onsetList = wordList.onsetList3;
			if(randDiff==3)onsetList = wordList.onsetList4;
			if(randDiff==4)onsetList = wordList.onsetList5;
			if(randDiff==5)onsetList = wordList.onsetList6;
			if(randDiff==6)onsetList = wordList.onsetList7;

			int randOnset = Random.Range(0,onsetList.Length);
			string pickedOnset = onsetList[randOnset];
			bool checkExists = true;
			bool dupeFound = false;

			//while(checkExists){
				foreach (string curOnset in pickedOnsets) {
					if(curOnset.Equals(pickedOnset)){
						dupeFound = true;
					}
				}
				
				if(!dupeFound)checkExists=false;
				pickedOnsets.Add(pickedOnset);

			onset.GetComponent<OnsetObject>().onsetText.text = pickedOnset;
			randDiff = randDiff + 1;
			onset.GetComponent<OnsetObject>().valueText.text = randDiff.ToString();
			//if(!onsetPressed)onsetPressed=true;

		}

	}

	void pickRimes () {

		foreach (GameObject rime in rimesList){

			int randDiff = Random.Range(min_difficulty_rime,max_difficulty_rime);
			string[] rimeList = {""};

			if(randDiff==0)rimeList = wordList.rimeList1;
			if(randDiff==1)rimeList = wordList.rimeList2;
			if(randDiff==2)rimeList = wordList.rimeList3;
			if(randDiff==3)rimeList = wordList.rimeList4;
			if(randDiff==4)rimeList = wordList.rimeList5;
			if(randDiff==5)rimeList = wordList.rimeList6;

			int randRime = Random.Range(0,rimeList.Length);
			string pickedRime = rimeList[randRime];
			bool checkExists = true;
			bool dupeFound = false;

			//while(checkExists){
			foreach (string curRime in pickedRimes) {
				if(curRime.Equals(pickedRime)){
					dupeFound = true;


				}
			}

			if(!dupeFound)checkExists=false;
			pickedOnsets.Add(pickedRime);

			rime.GetComponent<RimeObject>().rimeText.text = pickedRime;
			randDiff = randDiff + 1;
			rime.GetComponent<RimeObject>().valueText.text = randDiff.ToString();
			//if(!rimePressed)rimePressed=true;

		}

	}

	void checkScore() {

		if(score>=50&&level==1){ 
			level = 2;
			levelText.text = "2";
			timeLeft = timeLeft + 30;
			max_difficulty_rime = max_difficulty_rime + 1;
            int volOn = PlayerPrefs.GetInt("volume_on");
            if (volOn == 1) levelUpSound.Play();
            countdownAudio.Stop();
		} else if(score>=100&&level==2){ 
			level = 3;
			levelText.text = "3";
			timeLeft = timeLeft + 30;
			max_difficulty_rime = max_difficulty_rime + 1;
			max_difficulty_onset = max_difficulty_onset + 1;
            int volOn = PlayerPrefs.GetInt("volume_on");
            if (volOn == 1) levelUpSound.Play();
            countdownAudio.Stop();
		} else if(score>=150&&level==3){ 
			level = 4;
			levelText.text = "4";
			timeLeft = timeLeft + 30;
			max_difficulty_onset = max_difficulty_onset + 1;
            int volOn = PlayerPrefs.GetInt("volume_on");
            if (volOn == 1) levelUpSound.Play();
            countdownAudio.Stop();
		} else if(score>=200&&level==4){ 
			level = 5;
			levelText.text = "5";
			timeLeft = timeLeft + 30;
			max_difficulty_rime = max_difficulty_rime + 1;
            int volOn = PlayerPrefs.GetInt("volume_on");
            if (volOn == 1) levelUpSound.Play();
            countdownAudio.Stop();
		} else if(score>=250&&level==5){ 
			level = 6;
			levelText.text = "6";
			timeLeft = timeLeft + 30;
			max_difficulty_onset = max_difficulty_onset + 1;
            int volOn = PlayerPrefs.GetInt("volume_on");
            if (volOn == 1) levelUpSound.Play();
            countdownAudio.Stop();
		} else if(score>=300&&level==6){ 
			level = 7;
			levelText.text = "7";
			timeLeft = timeLeft + 30;
			max_difficulty_rime = max_difficulty_rime + 1;
            int volOn = PlayerPrefs.GetInt("volume_on");
            if (volOn == 1) levelUpSound.Play();
            countdownAudio.Stop();
		} else if(score>=350&&level==7){ 
			level = 8;
			levelText.text = "8";
			timeLeft = timeLeft + 30;
            int volOn = PlayerPrefs.GetInt("volume_on");
            if (volOn == 1) levelUpSound.Play();
            countdownAudio.Stop();
		} else if(score>=400&&level==8){ 
			level = 9;
			levelText.text = "9";
			timeLeft = timeLeft + 30;
            int volOn = PlayerPrefs.GetInt("volume_on");
            if (volOn == 1) levelUpSound.Play();
            countdownAudio.Stop();
		} else if(score>=450&&level==9){ 
			level = 10;
			levelText.text = "10";
			timeLeft = timeLeft + 30;
            int volOn = PlayerPrefs.GetInt("volume_on");
            if (volOn == 1) levelUpSound.Play();
            countdownAudio.Stop();
		}

	}

	void checkTime () {

        if(timeLeft==5){
            
            if(!countdownAudio.isPlaying){
                if(PlayerPrefs.GetInt("volume_on")==1){
                    countdownAudio.Play();
                }

            }

            countdownText.text = "5";
        } else if(timeLeft==4){
            countdownText.text = "4";
        } else if(timeLeft==3){
            countdownText.text = "3";
        } else if(timeLeft==2){
            countdownText.text = "2";
        } else if(timeLeft==1){
            countdownText.text = "1";
        } else {
            countdownText.text = " ";
        }

		if(timeLeft<=0){
			PlayerPrefs.SetString("tempScore",score.ToString());
			PlayerPrefs.SetString("tempWordsMade",wordsMade);
			if(score>0){
                if(!endingGame){
                    endingGame = true;
                    SceneManager.LoadScene("03 - Game Over Page", LoadSceneMode.Single);     
                }
			
			} else {
                if (!endingGame)
                {
                    endingGame = true;
                    SceneManager.LoadScene("01 - Main Menu", LoadSceneMode.Single);
                }
			}
		}

	}

	// Update is called once per frame
	void Update () {

		checkFooter();
		checkScore();
		checkTime();

        handleFades();

        if(score>=100&&PlayerPrefs.GetInt("free_mode")==1){
            PlayerPrefs.SetString("tempScore", score.ToString());
            PlayerPrefs.SetString("tempWordsMade", wordsMade);
            PlayerPrefs.SetInt("freeHighScore", 1);
            if (score > 0)
            {
                if (!endingGame)
                {
                    endingGame = true;
                    SceneManager.LoadScene("03 - Game Over Page", LoadSceneMode.Single);
                }

            }
            else
            {
                if (!endingGame)
                {
                    endingGame = true;
                    SceneManager.LoadScene("01 - Main Menu", LoadSceneMode.Single);
                }
            }
        }

		if(fadeIntro && introAlpha > 0.0f) {

			introAlpha -= 0.05f;
			Color tmpCol = introText.color;
			tmpCol.a = introAlpha;
			introText.color = tmpCol;

			tmpCol = introImage.color;
			tmpCol.a = introAlpha;
			introImage.color = tmpCol;
		} else if (fadeIntro && !(introAlpha > 0.0f)){ 
			fadeIntro = false;
			StartCoroutine(StartCountdown());
			introImageObj.SetActive(false);
			introTextObj.SetActive(false);
		}

		if(onsetPressed && rimePressed) {
			
			wordMade = false;
			tempWord = onsetTop.onsetText.text+rimeTop.rimeText.text;
			Debug.Log("tempWord: "+tempWord);
			Debug.Log("wordList: "+wordList.fullWordList.Count);
			for(int i = 0; i<wordList.fullWordList.Count; i++){

				string tmp = wordList.fullWordList[i];

				if (tmp.Equals(tempWord)) {

					wordMade = true;
					int scoreIncrease1 = int.Parse(onsetTop.valueText.text);
					int scoreIncrease2 = int.Parse(rimeTop.valueText.text);
					score = score + scoreIncrease1 + scoreIncrease2;
					scoreText.text = score.ToString();
                    wordMadeFooter.text = tempWord + " +" + (scoreIncrease1 + scoreIncrease2).ToString();
                    wordMadeAlpha = 1.0f;

                    if(footerShown) {

                        footerTime = 2.0f;

                    } else {

                        footerTime = 2.0f;
                        footerShown = true;

                    }

                    numWordsMade += 1;

                    if (freeMode && numWordsMade >= 5)
                    {

                    }
                    else
                    {
                        wordsMade = wordsMade + ", " + tempWord;
                    }

                    if(score>=100&&PlayerPrefs.GetInt("free_mode") == 1){
                        timeLeft = -99;
                    }

				}

			}

			if(!wordMade) {
				score = score-2;
				scoreText.text = score.ToString();
                wordMadeFooter.text = "-2";
                wordMadeAlpha = 1.0f;

                if (footerShown)
                {

                    footerTime = 2.0f;

                }
                else
                {

                    footerTime = 2.0f;
                    footerShown = true;

                }
			}

			StartCoroutine(HideTopWords());
			onsetPressed = false;
			rimePressed = false;
            //GameAnimations tempGameAnimations = gameObject.AddComponent(GameAnimations);
			foreach (GameObject onset in onsetsList){
				if(onset.GetComponent<OnsetObject>().onsetPressed && wordMade){
                    curOnsetImage = onset.GetComponent<OnsetObject>().onsetImage;

                    gameAnimations.gameController = gameController;
                    gameAnimations.onsetObject = onset;


                  //  fadeToGreen = true;
                    //onset.GetComponent<OnsetObject>().onsetImage.color = Color.green;
                 //   StartCoroutine(resetOnsetColor(onset.GetComponent<OnsetObject>().onsetImage));
				//	replaceOnset(onset);
				}
                if (onset.GetComponent<OnsetObject>().onsetPressed && !wordMade)
                {
                //    onset.GetComponent<OnsetObject>().onsetImage.color = Color.red;
                    curOnsetImage = onset.GetComponent<OnsetObject>().onsetImage;
                 //   fadeToRed = true;
                 //   StartCoroutine(resetOnsetColor(onset.GetComponent<OnsetObject>().onsetImage));
                //    replaceOnset(onset);
                }

				onset.GetComponent<OnsetObject>().onsetPressed = false;
			}
			foreach (GameObject rime in rimesList){
				if(rime.GetComponent<RimeObject>().rimePressed && wordMade){
                    curRimeImage = rime.GetComponent<RimeObject>().rimeImage;

                    gameAnimations.gameController = gameController;
                    gameAnimations.rimeObject = rime;

                    gameAnimations.beginRotate();

                 //   fadeToGreen = true;
                    //rime.GetComponent<RimeObject>().rimeImage.color = Color.green;
                 //   StartCoroutine(resetRimeColor(rime.GetComponent<RimeObject>().rimeImage));
				//	replaceRime(rime);
				}
                if (rime.GetComponent<RimeObject>().rimePressed && !wordMade)
                {
                    curRimeImage = rime.GetComponent<RimeObject>().rimeImage;
                //    fadeToRed = true;
                    //rime.GetComponent<RimeObject>().rimeImage.color = Color.red;
                //    StartCoroutine(resetRimeColor(rime.GetComponent<RimeObject>().rimeImage));
                //    replaceRime(rime);
                }

				rime.GetComponent<RimeObject>().rimePressed = false;
			}

			if(wordMade){
				// If the volume is on, play the 'good' sound.
				int volOn = PlayerPrefs.GetInt("volume_on");
				if(volOn==1)dingGoodSound.Play();
			} else {
				// If the volume is on, play the 'bad' sound.
				int volOn = PlayerPrefs.GetInt("volume_on");
				if(volOn==1)dingBadSound.Play();
			}

			wordMade = false;
		}

		if(hideWordCountDown == 0){

			onsetTopObj.GetComponent<OnsetTop>().shouldHide = true;
			rimeTopObj.GetComponent<RimeTop>().shouldHide = true;
			hideWordCountDown = 1;

		}

	}

    public IEnumerator resetOnsetColor(Image onsetImage){
        yield return new WaitForSeconds(0.7f);
        onsetImage.color = Color.white;
    }

    public IEnumerator resetRimeColor(Image rimeImage)
    {
        yield return new WaitForSeconds(0.7f);
       rimeImage.color = Color.white;
    }

	public IEnumerator HideTopWords()
	{
		// While there is still time left...
		while (hideWordCountDown > 0)
		{
			// Wait for a second...
			yield return new WaitForSeconds(0.5f);
			// Subtract a second from our time.
			hideWordCountDown--;
		}
	}

	// Game timer co-routine.
	//
	// • A co-routine is a function that runs on
	// a seprate CPU 'thread' so it doesn't mess 
	// with the UI's 'thread,' causing the app to
	// feel less 'glitchy.'
	public IEnumerator StartCountdown()
	{
		// While there is still time left...
		while (timeLeft > 0)
		{
			// Wait for a second...
			yield return new WaitForSeconds(1.0f);
			// Subtract a second from our time.
			timeLeft--;
			// Update the header's text.
            if(timeLeft >= 10){
                timeText.text = "0:" + timeLeft;
            } else {
                timeText.text = "0:0" + timeLeft;
            }
			
		}
	}

	public IEnumerator IntroCountdown()
	{
		// While there is still time left...
		while (introCountDown > 0)
		{
			// Wait for a second...
			yield return new WaitForSeconds(1.0f);
			// Subtract a second from our time.
			introCountDown--;

			if(introCountDown == 2)introText.text = "set!";
			if(introCountDown == 1)introText.text = "go!";
			if(introCountDown == 0)fadeIntro = true;
			// Update the header's text.
			Debug.Log("intro: "+introCountDown);
		}
	}

	void initObjects () {

		onsetTopObj = GameObject.FindGameObjectWithTag("onset_top");
		rimeTopObj = GameObject.FindGameObjectWithTag("rime_top");

		scoreTextObj = GameObject.FindGameObjectWithTag("score_text");
		timeTextObj = GameObject.FindGameObjectWithTag("time_text");
		levelTextObj = GameObject.FindGameObjectWithTag("level_text");

		onsetsList = GameObject.FindGameObjectsWithTag("onset");
		rimesList = GameObject.FindGameObjectsWithTag("rime");

		onsetTopImage = onsetTopObj.GetComponent<Image>();
		rimeTopImage = rimeTopObj.GetComponent<Image>();

		scoreText = scoreTextObj.GetComponent<Text>();
		timeText = timeTextObj.GetComponent<Text>();
		levelText = levelTextObj.GetComponent<Text>();

		scoreText.text = "0";
		timeText.text = "1:00";
		levelText.text = "1";

		onsetTop = onsetTopObj.GetComponent<OnsetTop>();
		rimeTop = rimeTopObj.GetComponent<RimeTop>();

		Color footerColor = wordMadeFooter.color;
		footerColor.a = wordMadeAlpha;
		wordMadeFooter.color = footerColor;


	}

	public void replaceOnset (GameObject onset) {
		int randDiff = Random.Range(min_difficulty_onset,max_difficulty_onset);
		string[] onsetList = {""};

		if(randDiff==0)onsetList = wordList.onsetList1;
		if(randDiff==1)onsetList = wordList.onsetList2;
		if(randDiff==2)onsetList = wordList.onsetList3;
		if(randDiff==3)onsetList = wordList.onsetList4;
		if(randDiff==4)onsetList = wordList.onsetList5;
		if(randDiff==5)onsetList = wordList.onsetList6;
		if(randDiff==6)onsetList = wordList.onsetList7;

		int randOnset = Random.Range(0,onsetList.Length);
		string pickedOnset = onsetList[randOnset];
		bool checkExists = true;
		bool dupeFound = false;

		//while(checkExists){
		foreach (string curOnset in pickedOnsets) {
			if(curOnset.Equals(pickedOnset)){
				dupeFound = true;
			}
		}

		if(!dupeFound)checkExists=false;
		pickedOnsets.Add(pickedOnset);

		onset.GetComponent<OnsetObject>().onsetText.text = pickedOnset;
		randDiff = randDiff + 1;
		onset.GetComponent<OnsetObject>().valueText.text = randDiff.ToString();
	}

	public void replaceRime (GameObject rime) {

		int randDiff = Random.Range(min_difficulty_rime,max_difficulty_rime);
		string[] rimeList = {""};

		if(randDiff==0)rimeList = wordList.rimeList1;
		if(randDiff==1)rimeList = wordList.rimeList2;
		if(randDiff==2)rimeList = wordList.rimeList3;
		if(randDiff==3)rimeList = wordList.rimeList4;
		if(randDiff==4)rimeList = wordList.rimeList5;
		if(randDiff==5)rimeList = wordList.rimeList6;

		int randRime = Random.Range(0,rimeList.Length);
		string pickedRime = rimeList[randRime];
		bool checkExists = true;
		bool dupeFound = false;

		//while(checkExists){
		foreach (string curRime in pickedRimes) {
			if(curRime.Equals(pickedRime)){
				dupeFound = true;


			}
		}

		if(!dupeFound)checkExists=false;
		pickedOnsets.Add(pickedRime);

		rime.GetComponent<RimeObject>().rimeText.text = pickedRime;
		randDiff = randDiff + 1;
		rime.GetComponent<RimeObject>().valueText.text = randDiff.ToString();

        gameAnimations.finishRotate();
	}

	void checkFooter () {
		
        if(footerShown) {
            if (footerTime > 0.0f)
            {
                wordMadeAlpha = 1.0f;
                footerTime -= 0.033f;
            } else {
                wordMadeAlpha = 0.0f;
                footerShown = false;
            }
        } else {
            
        }

        Color tempCol = wordMadeFooter.color;
        tempCol.a = wordMadeAlpha;
        wordMadeFooter.color = tempCol;

	}

	public IEnumerator HideFooter()
	{
		// While there is still time left...
		while (hideFooterCountDown > 0)
		{
			// Wait for a second...
			yield return new WaitForSeconds(0.5f);
            // Subtract a second from our time.
            //if(hideFooter )
            wordMadeAlpha = 0.0f;
		}
	}

	public void resetValues () {
		score = 0;
		level = 1;
		introAlpha = 1.0f;
		fadeIntro = false;
		hideWordCountDown = 1;
		hideFooterCountDown = 1;
		min_difficulty_onset = 0;
		max_difficulty_onset = 2;
		min_difficulty_rime = 0;
		max_difficulty_rime = 2;
		onsetPressed = false;
		rimePressed = false;
		hasStarted = false;
		timeLeftToStart = 3;
		pickedOnsets = new List<string>();
		pickedRimes = new List<string>();
		tempWord = "";
		wordMade = false;
		wordMadeAlpha = 0.0f;
		showFooter = false;
		hideFooter = false;
		introCountDown = 3;
		wordsMade = "";
		timeLeft = 60;
	}

    void handleFades() {
        if (fadeToGreen)
        {
            if (curCol > 0.0f)
            {
                curCol = curCol - 0.2f;
                Color tmpCol = new Color(curCol, 1.0f, curCol);
                curOnsetImage.color = tmpCol;
                curRimeImage.color = tmpCol;
            }
            else
            {
                fadeToGreen = false;
                doneFadeToGreen = true;
            }
        }

        if (doneFadeToGreen)
        {
            if (curCol < 1.0f)
            {
                curCol = curCol + 0.2f;
                Color tmpCol = new Color(curCol, 1.0f, curCol);
                curOnsetImage.color = tmpCol;
                curRimeImage.color = tmpCol;
            }
            else
            {
                curCol = 1.0f;
                Color tmpCol = new Color(curCol, 1.0f, curCol);
                curOnsetImage.color = tmpCol;
                curRimeImage.color = tmpCol;
                doneFadeToGreen = false;
            }
        }
        if (fadeToRed)
        {
            if (curCol > 0.5f)
            {
                curCol = curCol - 0.2f;
                Color tmpCol = new Color(1.0f, curCol, curCol);
                curOnsetImage.color = tmpCol;
                curRimeImage.color = tmpCol;
            }
            else
            {
                fadeToRed = false;
                doneFadeToRed = true;
            }
        }

        if (doneFadeToRed)
        {
            if (curCol < 1.0f)
            {
                curCol = curCol + 0.2f;
                Color tmpCol = new Color(1.0f, curCol, curCol);
                curOnsetImage.color = tmpCol;
                curRimeImage.color = tmpCol;
            }
            else
            {
                curCol = 1.0f;
                Color tmpCol = new Color(1.0f, curCol, curCol);
                curOnsetImage.color = tmpCol;
                curRimeImage.color = tmpCol;
                doneFadeToRed = false;
            }
        }
    }

    public void checkVolume() {

        int volOn = PlayerPrefs.GetInt("volume_on");

        if (volOn == 1)
        {
            if (PlayerPrefs.GetString("cur_theme").Equals("pastel"))
            {
                volumeButtonImage.sprite = volumeImageBlackOn;
            }
            else
            {
                volumeButtonImage.sprite = volumeImageWhiteOn;
            }
        }
        else if (volOn == 0)
        {
            if (PlayerPrefs.GetString("cur_theme").Equals("pastel"))
            {
                volumeButtonImage.sprite = volumeImageBlackOff;
            }
            else
            {
                volumeButtonImage.sprite = volumeImageWhiteOff;
            }
        }

    }

}
