﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;
using System.IO;

public class MenuManager : MonoBehaviour {

	public GameObject menuObject;
	public GameObject highScoresObject;
	public GameObject optionsObject;
	public GameObject helpObject;

	public GameObject logoutPopupObject;

	public MenuAnimations menuAnimator;
	public HighScoreAnimations highScoreAnimator;
	public OptionsAnimations optionsAnimator;
	public HelpAnimations helpAnimator;
	public LogoutPopupAnimations logoutPopupAnimator;
    public HighScoreManager highScoreManager;

	public bool moveNextPage = false;
	public string nextPage = "";

	public AudioSource menuSound;

	public string current_theme;
	public string current_sound;

	public ThemeManager themeManager;

	public GameObject scrollingBgObj;

	public Text loginButtonText;
	public Text loginButtonBottomText;

    public GameObject mainMenuProfileImageObj;
    public GameObject highScoreProfileImageObj;

    public List<Scores> highScoreList;

    public RawImage mainMenuProfileImage;
    public RawImage highScoreProfileImage;

    public GameObject loginButtonObj;
    public GameObject buyProButtonObj;
    public bool freeMode = false;

	// Use this for initialization
	void Awake () {
        // turn on free mode 
        freeMode = false;

        PlayerPrefs.SetInt("free_mode", 0);
        PlayerPrefs.SetInt("pro_themes", 1);

        if(freeMode){
            PlayerPrefs.SetString("cur_theme", "classic");
            PlayerPrefs.SetInt("loggedIn", 0);
            PlayerPrefs.SetString("cur_theme", "classic");
            loginButtonObj.SetActive(false);
            buyProButtonObj.SetActive(true);
        } else {
            loginButtonObj.SetActive(true);
            buyProButtonObj.SetActive(false);
        }

		// Set the object containing the 
		// menu buttons to active.
		menuObject.SetActive(true);
		// And let it know to fade in.
		menuAnimator.fadeIn = true;

		// If the volume preference is on, 
		// play the menu jingle.
		if(PlayerPrefs.HasKey("cur_theme")){
			current_theme = PlayerPrefs.GetString("cur_theme");
		} else {
			PlayerPrefs.SetString("cur_theme", "classic");
			current_theme = "classic";
		}

		if(PlayerPrefs.HasKey("cur_sound")){
			current_theme = PlayerPrefs.GetString("cur_sound");
		} else {
			PlayerPrefs.SetString("cur_sound", "classic");
			current_sound = "classic";
		}

		setCurrentTheme();

		int volOn = PlayerPrefs.GetInt("volume_on");
		if(volOn==1)menuSound.Play();

		// If the player is logged in...
		if(PlayerPrefs.GetInt("loggedIn")==1){
            loginButtonText.text = "Logged in as: "+PlayerPrefs.GetString("tempUsername")+ " (not you?)";
            loginButtonBottomText.text = "logged in as: "+PlayerPrefs.GetString("tempUsername")+ " (not you?)";
            if(PlayerPrefs.GetString("login_type")=="fb"){
                string fileName = Application.persistentDataPath + "/" + "fbprofile.png";
                byte[] bytes;
                bytes = System.IO.File.ReadAllBytes(fileName);
                Texture2D tempTex = new Texture2D(1, 1);
                tempTex.LoadImage(bytes);
                mainMenuProfileImage.texture = tempTex;
                highScoreProfileImage.texture = tempTex;

                mainMenuProfileImageObj.SetActive(true);
                highScoreProfileImageObj.SetActive(false);
            } else {
                mainMenuProfileImageObj.SetActive(false);
                highScoreProfileImageObj.SetActive(false);
            }

        }else
        {
            mainMenuProfileImageObj.SetActive(false);
            highScoreProfileImageObj.SetActive(false);
        }


        highScoreList = highScoreManager.GetHighScore();
        Debug.Log("high scores: " + highScoreList.ToString());

	}

	public void setCurrentTheme() {

		Debug.Log("cur_theme: "+PlayerPrefs.GetString("cur_theme"));

		if(PlayerPrefs.GetString("cur_sound").Equals("classic")){
			menuSound.clip = themeManager.jingleClassic;
		} 
		if(PlayerPrefs.GetString("cur_sound").Equals("techno")){
			menuSound.clip = themeManager.jingleTechno;
		} 
		if(PlayerPrefs.GetString("cur_sound").Equals("bamboo")){
			menuSound.clip = themeManager.jingleBamboo;
		} 
		if(PlayerPrefs.GetString("cur_sound").Equals("night")){
			menuSound.clip = themeManager.jingleNight;
		} 
		if(PlayerPrefs.GetString("cur_sound").Equals("candy")){
			menuSound.clip = themeManager.jingleCandy;
		} 
		if(PlayerPrefs.GetString("cur_sound").Equals("pastel")){
			menuSound.clip = themeManager.jinglePastel;
		} 

		if(PlayerPrefs.GetString("cur_theme").Equals("classic")){

			Debug.Log("classic");

			menuAnimator.logoImage.sprite = themeManager.logoImgClassic;
			menuAnimator.newGameImage.sprite = themeManager.newGameImgClassic;
			menuAnimator.highScoresImage.sprite = themeManager.highScoresImgClassic;
			menuAnimator.optionsImage.sprite = themeManager.optionsImgClassic;
			menuAnimator.helpImage.sprite = themeManager.helpImgClassic;

			if(PlayerPrefs.GetInt("volume_on")==1){
				menuAnimator.volumeImage.sprite = themeManager.volOnWhite;
			} else {
				menuAnimator.volumeImage.sprite = themeManager.volOffWhite;
			}

			highScoreAnimator.pageContainerImage.sprite = themeManager.containerImgClassic;
			optionsAnimator.pageContainerImage.sprite = themeManager.containerImgClassic;
			helpAnimator.pageContainerImage.sprite = themeManager.containerImgClassic;

			highScoreAnimator.mainMenuBtnImage.sprite = themeManager.mainMenuImgClassic;
			optionsAnimator.mainMenuBtnImage.sprite = themeManager.mainMenuImgClassic;
			helpAnimator.mainMenuBtnImage.sprite = themeManager.mainMenuImgClassic;

			highScoreAnimator.newGameBtnImage.sprite = themeManager.newGameBtnImgClassic;
			optionsAnimator.newGameBtnImage.sprite = themeManager.newGameBtnImgClassic;
			helpAnimator.newGameBtnImage.sprite = themeManager.newGameBtnImgClassic;

			highScoreAnimator.logoImage.sprite = themeManager.logoImgClassic;
			optionsAnimator.logoImage.sprite = themeManager.logoImgClassic;
			helpAnimator.logoImage.sprite = themeManager.logoImgClassic;

			scrollingBgObj.GetComponent<Renderer>().material = themeManager.bgMatClassic;

			highScoreAnimator.titleText.color = Color.white;
			highScoreAnimator.titleShadowText.color = Color.black;

			optionsAnimator.titleText.color = Color.white;
			optionsAnimator.titleShadowText.color = Color.black;
			optionsAnimator.skinsText.color = Color.white;
			optionsAnimator.skinsShadowText.color = Color.black;
			optionsAnimator.soundsText.color = Color.white;
			optionsAnimator.soundsShadowText.color = Color.black;

			helpAnimator.titleText.color = Color.white;
			helpAnimator.titleShadowText.color = Color.black;

		} else if(PlayerPrefs.GetString("cur_theme").Equals("techno")){

			Debug.Log("techno");

			menuAnimator.logoImage.sprite = themeManager.logoImgTechno;
			menuAnimator.newGameImage.sprite = themeManager.newGameImgTechno;
			menuAnimator.highScoresImage.sprite = themeManager.highScoresImgTechno;
			menuAnimator.optionsImage.sprite = themeManager.optionsImgTechno;
			menuAnimator.helpImage.sprite = themeManager.helpImgTechno;
			if(PlayerPrefs.GetInt("volume_on")==1){
				menuAnimator.volumeImage.sprite = themeManager.volOnWhite;
			} else {
				menuAnimator.volumeImage.sprite = themeManager.volOffWhite;
			}

			highScoreAnimator.pageContainerImage.sprite = themeManager.containerImgTechno;
			optionsAnimator.pageContainerImage.sprite = themeManager.containerImgTechno;
			helpAnimator.pageContainerImage.sprite = themeManager.containerImgTechno;

			highScoreAnimator.mainMenuBtnImage.sprite = themeManager.mainMenuImgTechno;
			optionsAnimator.mainMenuBtnImage.sprite = themeManager.mainMenuImgTechno;
			helpAnimator.mainMenuBtnImage.sprite = themeManager.mainMenuImgTechno;

			highScoreAnimator.newGameBtnImage.sprite = themeManager.newGameBtnImgTechno;
			optionsAnimator.newGameBtnImage.sprite = themeManager.newGameBtnImgTechno;
			helpAnimator.newGameBtnImage.sprite = themeManager.newGameBtnImgTechno;

			highScoreAnimator.logoImage.sprite = themeManager.logoImgTechno;
			optionsAnimator.logoImage.sprite = themeManager.logoImgTechno;
			helpAnimator.logoImage.sprite = themeManager.logoImgTechno;

			scrollingBgObj.GetComponent<Renderer>().material = themeManager.bgMatTechno;

			highScoreAnimator.titleText.color = Color.white;
			highScoreAnimator.titleShadowText.color = Color.black;

			optionsAnimator.titleText.color = Color.white;
			optionsAnimator.titleShadowText.color = Color.black;
			optionsAnimator.skinsText.color = Color.white;
			optionsAnimator.skinsShadowText.color = Color.black;
			optionsAnimator.soundsText.color = Color.white;
			optionsAnimator.soundsShadowText.color = Color.black;

			helpAnimator.titleText.color = Color.white;
			helpAnimator.titleShadowText.color = Color.black;

		} else if(PlayerPrefs.GetString("cur_theme").Equals("bamboo")){

			Debug.Log("bamboo");

			menuAnimator.logoImage.sprite = themeManager.logoImgBamboo;
			menuAnimator.newGameImage.sprite = themeManager.newGameImgBamboo;
			menuAnimator.highScoresImage.sprite = themeManager.highScoresImgBamboo;
			menuAnimator.optionsImage.sprite = themeManager.optionsImgBamboo;
			menuAnimator.helpImage.sprite = themeManager.helpImgBamboo;
			if(PlayerPrefs.GetInt("volume_on")==1){
				menuAnimator.volumeImage.sprite = themeManager.volOnWhite;
			} else {
				menuAnimator.volumeImage.sprite = themeManager.volOffWhite;
			}

			highScoreAnimator.pageContainerImage.sprite = themeManager.containerImgBamboo;
			optionsAnimator.pageContainerImage.sprite = themeManager.containerImgBamboo;
			helpAnimator.pageContainerImage.sprite = themeManager.containerImgBamboo;

			highScoreAnimator.mainMenuBtnImage.sprite = themeManager.mainMenuImgBamboo;
			optionsAnimator.mainMenuBtnImage.sprite = themeManager.mainMenuImgBamboo;
			helpAnimator.mainMenuBtnImage.sprite = themeManager.mainMenuImgBamboo;

			highScoreAnimator.newGameBtnImage.sprite = themeManager.newGameBtnImgBamboo;
			optionsAnimator.newGameBtnImage.sprite = themeManager.newGameBtnImgBamboo;
			helpAnimator.newGameBtnImage.sprite = themeManager.newGameBtnImgBamboo;

			highScoreAnimator.logoImage.sprite = themeManager.logoImgBamboo;
			optionsAnimator.logoImage.sprite = themeManager.logoImgBamboo;
			helpAnimator.logoImage.sprite = themeManager.logoImgBamboo;

			scrollingBgObj.GetComponent<Renderer>().material = themeManager.bgMatBamboo;

			highScoreAnimator.titleText.color = Color.white;
			highScoreAnimator.titleShadowText.color = Color.black;

			optionsAnimator.titleText.color = Color.white;
			optionsAnimator.titleShadowText.color = Color.black;
			optionsAnimator.skinsText.color = Color.white;
			optionsAnimator.skinsShadowText.color = Color.black;
			optionsAnimator.soundsText.color = Color.white;
			optionsAnimator.soundsShadowText.color = Color.black;

			helpAnimator.titleText.color = Color.white;
			helpAnimator.titleShadowText.color = Color.black;

		} else if(PlayerPrefs.GetString("cur_theme").Equals("night")){

			Debug.Log("night");

			menuAnimator.logoImage.sprite = themeManager.logoImgNight;
			menuAnimator.newGameImage.sprite = themeManager.newGameImgNight;
			menuAnimator.highScoresImage.sprite = themeManager.highScoresImgNight;
			menuAnimator.optionsImage.sprite = themeManager.optionsImgNight;
			menuAnimator.helpImage.sprite = themeManager.helpImgNight;
			if(PlayerPrefs.GetInt("volume_on")==1){
				menuAnimator.volumeImage.sprite = themeManager.volOnWhite;
			} else {
				menuAnimator.volumeImage.sprite = themeManager.volOffWhite;
			}

			highScoreAnimator.pageContainerImage.sprite = themeManager.containerImgNight;
			optionsAnimator.pageContainerImage.sprite = themeManager.containerImgNight;
			helpAnimator.pageContainerImage.sprite = themeManager.containerImgNight;

			highScoreAnimator.mainMenuBtnImage.sprite = themeManager.mainMenuImgNight;
			optionsAnimator.mainMenuBtnImage.sprite = themeManager.mainMenuImgNight;
			helpAnimator.mainMenuBtnImage.sprite = themeManager.mainMenuImgNight;

			highScoreAnimator.newGameBtnImage.sprite = themeManager.newGameBtnImgNight;
			optionsAnimator.newGameBtnImage.sprite = themeManager.newGameBtnImgNight;
			helpAnimator.newGameBtnImage.sprite = themeManager.newGameBtnImgNight;

			highScoreAnimator.logoImage.sprite = themeManager.logoImgNight;
			optionsAnimator.logoImage.sprite = themeManager.logoImgNight;
			helpAnimator.logoImage.sprite = themeManager.logoImgNight;

			scrollingBgObj.GetComponent<Renderer>().material = themeManager.bgMatNight;

			highScoreAnimator.titleText.color = Color.white;
			highScoreAnimator.titleShadowText.color = Color.black;

			optionsAnimator.titleText.color = Color.white;
			optionsAnimator.titleShadowText.color = Color.black;
			optionsAnimator.skinsText.color = Color.white;
			optionsAnimator.skinsShadowText.color = Color.black;
			optionsAnimator.soundsText.color = Color.white;
			optionsAnimator.soundsShadowText.color = Color.black;

			helpAnimator.titleText.color = Color.white;
			helpAnimator.titleShadowText.color = Color.black;

		} else if(PlayerPrefs.GetString("cur_theme").Equals("candy")){

			Debug.Log("candy");

			menuAnimator.logoImage.sprite = themeManager.logoImgCandy;
			menuAnimator.newGameImage.sprite = themeManager.newGameImgCandy;
			menuAnimator.highScoresImage.sprite = themeManager.highScoresImgCandy;
			menuAnimator.optionsImage.sprite = themeManager.optionsImgCandy;
			menuAnimator.helpImage.sprite = themeManager.helpImgCandy;
			if(PlayerPrefs.GetInt("volume_on")==1){
				menuAnimator.volumeImage.sprite = themeManager.volOnWhite;
			} else {
				menuAnimator.volumeImage.sprite = themeManager.volOffWhite;
			}

			highScoreAnimator.pageContainerImage.sprite = themeManager.containerImgCandy;
			optionsAnimator.pageContainerImage.sprite = themeManager.containerImgCandy;
			helpAnimator.pageContainerImage.sprite = themeManager.containerImgCandy;

			highScoreAnimator.mainMenuBtnImage.sprite = themeManager.mainMenuImgCandy;
			optionsAnimator.mainMenuBtnImage.sprite = themeManager.mainMenuImgCandy;
			helpAnimator.mainMenuBtnImage.sprite = themeManager.mainMenuImgCandy;

			highScoreAnimator.newGameBtnImage.sprite = themeManager.newGameBtnImgCandy;
			optionsAnimator.newGameBtnImage.sprite = themeManager.newGameBtnImgCandy;
			helpAnimator.newGameBtnImage.sprite = themeManager.newGameBtnImgCandy;

			highScoreAnimator.logoImage.sprite = themeManager.logoImgCandy;
			optionsAnimator.logoImage.sprite = themeManager.logoImgCandy;
			helpAnimator.logoImage.sprite = themeManager.logoImgCandy;

			scrollingBgObj.GetComponent<Renderer>().material = themeManager.bgMatCandy;

			highScoreAnimator.titleText.color = Color.white;
			highScoreAnimator.titleShadowText.color = Color.black;

			optionsAnimator.titleText.color = Color.white;
			optionsAnimator.titleShadowText.color = Color.black;
			optionsAnimator.skinsText.color = Color.white;
			optionsAnimator.skinsShadowText.color = Color.black;
			optionsAnimator.soundsText.color = Color.white;
			optionsAnimator.soundsShadowText.color = Color.black;

			helpAnimator.titleText.color = Color.white;
			helpAnimator.titleShadowText.color = Color.black;

		} else if(PlayerPrefs.GetString("cur_theme").Equals("pastel")){

			Debug.Log("pastel");

			menuAnimator.logoImage.sprite = themeManager.logoImgPastel;
			menuAnimator.newGameImage.sprite = themeManager.newGameImgPastel;
			menuAnimator.highScoresImage.sprite = themeManager.highScoresImgPastel;
			menuAnimator.optionsImage.sprite = themeManager.optionsImgPastel;
			menuAnimator.helpImage.sprite = themeManager.helpImgPastel;
			if(PlayerPrefs.GetInt("volume_on")==1){
				menuAnimator.volumeImage.sprite = themeManager.volOnBlack;
			} else {
				menuAnimator.volumeImage.sprite = themeManager.volOffBlack;
			}

			highScoreAnimator.pageContainerImage.sprite = themeManager.containerImgPastel;
			optionsAnimator.pageContainerImage.sprite = themeManager.containerImgPastel;
			helpAnimator.pageContainerImage.sprite = themeManager.containerImgPastel;

			highScoreAnimator.mainMenuBtnImage.sprite = themeManager.mainMenuImgPastel;
			optionsAnimator.mainMenuBtnImage.sprite = themeManager.mainMenuImgPastel;
			helpAnimator.mainMenuBtnImage.sprite = themeManager.mainMenuImgPastel;

			highScoreAnimator.newGameBtnImage.sprite = themeManager.newGameBtnImgPastel;
			optionsAnimator.newGameBtnImage.sprite = themeManager.newGameBtnImgPastel;
			helpAnimator.newGameBtnImage.sprite = themeManager.newGameBtnImgPastel;

			highScoreAnimator.logoImage.sprite = themeManager.logoImgPastel;
			optionsAnimator.logoImage.sprite = themeManager.logoImgPastel;
			helpAnimator.logoImage.sprite = themeManager.logoImgPastel;

			highScoreAnimator.titleText.color = Color.black;
			highScoreAnimator.titleShadowText.color = Color.white;

			//highScoreAnimator.nameText.color = Color.black;
			//highScoreAnimator.scoreText.color = Color.black;

			optionsAnimator.titleText.color = Color.black;
			optionsAnimator.titleShadowText.color = Color.white;
			optionsAnimator.skinsText.color = Color.black;
			optionsAnimator.skinsShadowText.color = Color.white;
			optionsAnimator.soundsText.color = Color.black;
			optionsAnimator.soundsShadowText.color = Color.white;

			helpAnimator.titleText.color = Color.black;
			helpAnimator.titleShadowText.color = Color.white;

			scrollingBgObj.GetComponent<Renderer>().material = themeManager.bgMatPastel;

		}

	}

	// Command to start a new game.
	public void newGamePressed () {
		// The actual code to start the new game
		// is handled in the animation script, 
		// since it only happens when the screen
		// has completely faded to black.
		menuAnimator.startNewGame();
	}

	// Show the High Scores submenu.
	public void highScoresPressed () {
		// Make sure the page knows we're not logging in.
		PlayerPrefs.SetInt("mainMenuLogin",0);
		// Turn off the other submenus...
		optionsObject.SetActive(false);
		helpObject.SetActive(false);

		// Enable this one...
		highScoresObject.SetActive(true);
		// And prep the animations.
		menuAnimator.fadeIn = false;
		menuAnimator.fadeOut = true;
		moveNextPage = true;
		nextPage = "highScores";

        if (PlayerPrefs.GetInt("logged_in") == 1)
        {
            if (PlayerPrefs.GetString("login_type") == "fb")
            {
                mainMenuProfileImageObj.SetActive(false);
                highScoreProfileImageObj.SetActive(true);
            }
            else
            {
                mainMenuProfileImageObj.SetActive(false);
                highScoreProfileImageObj.SetActive(false);
            }
        } else {
            mainMenuProfileImageObj.SetActive(false);
            highScoreProfileImageObj.SetActive(false);
        }
	}

	// Show the Options submenu.
	public void optionsPressed () {
		// Turn off the other submenus...
		highScoresObject.SetActive(false);
		helpObject.SetActive(false);
		// Enable this one...
		optionsObject.SetActive(true);
		// And prep the animations.
		menuAnimator.fadeIn = false;
		menuAnimator.fadeOut = true;
		moveNextPage = true;
		nextPage = "options";

        //    mainMenuProfileImageObj.SetActive(false);
        //    highScoreProfileImageObj.SetActive(false);


	}

	public void mainMenuLoginPressed () {
		if(PlayerPrefs.GetInt("loggedIn")==0){
		// Make sure the page knows we want to login.
		PlayerPrefs.SetInt("mainMenuLogin",1);
		// Turn off the other submenus...
		optionsObject.SetActive(false);
		helpObject.SetActive(false);
		// Enable this one...
		highScoresObject.SetActive(true);
		// And prep the animations.
		menuAnimator.fadeIn = false;
		menuAnimator.fadeOut = true;
		moveNextPage = true;
		nextPage = "highScores";
		} else {


			logoutPopupObject.SetActive(true);
			logoutPopupAnimator.fadeIn = true;
			
		}


	}

	// Show the Help submenu.
	public void helpPressed () {
		// Turn off the other submenus...
		highScoresObject.SetActive(false);
		optionsObject.SetActive(false);
		// Enable this one...
		helpObject.SetActive(true);
		// And prep the animations.
		menuAnimator.fadeIn = false;
		menuAnimator.fadeOut = true;
		moveNextPage = true;
		nextPage = "help";
      //  mainMenuProfileImageObj.SetActive(false);
       // highScoreProfileImageObj.SetActive(false);

	}
	
	// Update is called once per frame
	void Update () {


		if(moveNextPage && menuAnimator.nextPage) {

			menuAnimator.nextPage = false;

			if(nextPage.Equals("highScores")){

				menuObject.SetActive(false);
				highScoresObject.SetActive(true);

				highScoreAnimator.fadeIn = true;



			} else if(nextPage.Equals("options")){

				menuObject.SetActive(false);
				optionsObject.SetActive(true);

				optionsAnimator.fadeIn = true;

			} else if(nextPage.Equals("help")){

				menuObject.SetActive(false);
				optionsObject.SetActive(true);

				helpAnimator.fadeIn = true;

			}

			moveNextPage = false;

		}

	}
}
